==> smallmind-phalanx-5.8.0-sources.jar: org/smallmind/phalanx/wire/signal/JavaSerializationSignalCodec.java <==
/*
 * Copyright (c) 2007 through 2024 David Berkman
 *
 * This file is part of the SmallMind Code Project.
 *
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 *
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 *
 * ...or...
 *
 * 2) The terms of the Apache License, Version 2.0.
 *
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 *
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.phalanx.wire.signal;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import javax.ws.rs.core.MediaType;

public class JavaSerializationSignalCodec implements SignalCodec {

  @Override
  public String getContentType () {

    return MediaType.APPLICATION_OCTET_STREAM;
  }

  @Override
  public byte[] encode (Signal signal)
    throws IOException {

    try (ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(); ObjectOutputStream objectOutputStream = new ObjectOutputStream(byteArrayOutputStream)) {

      objectOutputStream.writeObject(signal);

      return byteArrayOutputStream.toByteArray();
    }
  }

  @Override
  public <S extends Signal> S decode (byte[] buffer, int offset, int len, Class<S> signalClass)
    throws IOException, ClassNotFoundException {

    try (ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(buffer, offset, len); ObjectInputStream objectInputStream = new ObjectInputStream(byteArrayInputStream)) {

      return signalClass.cast(objectInputStream.readObject());
    }
  }

  @Override
  public <T> T extractObject (Object value, Class<T> clazz) {

    return clazz.cast(value);
  }
}

==> smallmind-phalanx-6.3.0-sources.jar: org/smallmind/phalanx/wire/signal/JavaSerializationSignalCodec.java <==
/*
 * Copyright (c) 2007 through 2024 David Berkman
 *
 * This file is part of the SmallMind Code Project.
 *
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 *
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 *
 * ...or...
 *
 * 2) The terms of the Apache License, Version 2.0.
 *
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 *
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.phalanx.wire.signal;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import jakarta.ws.rs.core.MediaType;

public class JavaSerializationSignalCodec implements SignalCodec {

  @Override
  public String getContentType () {

    return MediaType.APPLICATION_OCTET_STREAM;
  }

  @Override
  public byte[] encode (Signal signal)
    throws IOException {

    try (ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(); ObjectOutputStream objectOutputStream = new ObjectOutputStream(byteArrayOutputStream)) {

      objectOutputStream.writeObject(signal);

      return byteArrayOutputStream.toByteArray();
    }
  }

  @Override
  public <S extends Signal> S decode (byte[] buffer, int offset, int len, Class<S> signalClass)
    throws IOException, ClassNotFoundException {

    try (ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(buffer, offset, len); ObjectInputStream objectInputStream = new ObjectInputStream(byteArrayInputStream)) {

      return signalClass.cast(objectInputStream.readObject());
    }
  }

  @Override
  public <T> T extractObject (Object value, Class<T> clazz) {

    return clazz.cast(value);
  }
}
